@@ -353,6 +353,7 @@ nsresult EphyWrapper::SetZoomOnDocshell (float aZoom, nsIDocShell *DocShell)
 					
 	nsCOMPtr<nsIDeviceContext> DeviceContext;
 	result = PresContext->GetDeviceContext (getter_AddRefs(DeviceContext));
+	if (NS_FAILED(result) || !DeviceContext) return NS_ERROR_FAILURE;
 
 	return DeviceContext->SetTextZoom (aZoom);
 }
@@ -503,6 +504,7 @@ nsresult EphyWrapper::FindSetProperties (const PRUnichar *search_string,
 	
 	finder->SetSearchString (search_string);
 	finder->SetMatchCase (case_sensitive);
+	finder->SetWrapFind (wrap_around);
 
 	return NS_OK;
 }
@@ -683,7 +685,7 @@ nsresult EphyWrapper::ForceEncoding (const char *encoding)
 								  &result);
 	if (NS_FAILED(result) || !mdv) return NS_ERROR_FAILURE;
 
-#if MOZILLA_SNAPSHOT > 8
+#if MOZILLA_SNAPSHOT > 9
 	result = mdv->SetForceCharacterSet (nsDependentCString(encoding));
 #else
 	result = mdv->SetForceCharacterSet (NS_ConvertUTF8toUCS2(encoding).get());
